@@ -5,10 +5,10 @@
 from exception import ElasticQueryError
 
 # Filter structures
-class FilterStructs( object ):
+class FilterStructs(object):
     type = 'filter'
 
-    def nested( self, path, musts=[], shoulds=[], must_nots=[] ):
+    def nested(self, path, musts=[], shoulds=[], must_nots=[]):
         must = [v[1] for v in musts]
         should = [v[1] for v in shoulds]
         must_not = [v[1] for v in must_nots]
@@ -26,7 +26,7 @@ class FilterStructs( object ):
             }
         }
 
-    def range( self, field, range_from=False, range_to=False ):
+    def range(self, field, range_from=False, range_to=False):
         data = {
             'range': {
                 field: {}
@@ -39,26 +39,26 @@ class FilterStructs( object ):
 
         return self.type, data
 
-    def prefix( self, **kwargs ):
+    def prefix(self, **kwargs):
         return self.type, {
             'prefix': kwargs
         }
 
-    def term( self, **kwargs ):
+    def term(self, **kwargs):
         return self.type, {
             'term': kwargs
         }
 
-    def terms( self, **kwargs ):
+    def terms(self, **kwargs):
         for key, value in kwargs.iteritems():
-            if not isinstance( value, list ):
-                raise ElasticQueryError( 'terms values must be lists' )
+            if not isinstance(value, list):
+                raise ElasticQueryError('terms values must be lists')
 
         return self.type, {
             'terms': kwargs
         }
 
-    def raw_string( self, string, default_operator='AND' ):
+    def raw_string(self, string, default_operator='AND'):
         if self.type == 'filter':
             return self.type, {
                 'query': {
@@ -76,21 +76,21 @@ class FilterStructs( object ):
                 }
             }
 
-    def string( self, default_operator='AND', list_operator='OR', **kwargs ):
+    def string(self, default_operator='AND', list_operator='OR', **kwargs):
         and_filters = []
         for key, value in kwargs.iteritems():
-            if isinstance( value, list ):
-                if len( value ) > 0:
+            if isinstance(value, list):
+                if len(value) > 0:
                     or_filters = []
 
                     for match in value:
-                        or_filters.append( '({0})'.format( match ))
+                        or_filters.append(u'({0})'.format(match))
 
-                    and_filters.append( '({0}:({1}))'.format( key, ' {0} '.format( list_operator ).join( or_filters )))
+                    and_filters.append(u'({0}:({1}))'.format(key, u' {0} '.format(list_operator).join(or_filters)))
             else:
-                and_filters.append( '{0}:{1}'.format( key, value ))
+                and_filters.append(u'{0}:{1}'.format(key, value))
 
-        query_string = ' {0} '.format( default_operator ).join( and_filters )
+        query_string = u' {0} '.format(default_operator).join(and_filters)
 
         if self.type == 'filter':
             return self.type, {
@@ -112,10 +112,10 @@ class FilterStructs( object ):
 
 # Query structures
 # inherits filters due to overlap
-class QueryStructs( FilterStructs ):
+class QueryStructs(FilterStructs):
     type = 'query'
 
-    def mlt( self, field, match, min_term_frequency=1, max_query_terms=False ):
+    def mlt(self, field, match, min_term_frequency=1, max_query_terms=False):
         settings = {
             'like_text': match
         }
@@ -133,72 +133,72 @@ class QueryStructs( FilterStructs ):
 
 # Aggregate structures
 # named, so only return self-contained dict
-class AggregateStructs( object ):
-    def sub( self, aggregate, **aggregates ):
+class AggregateStructs(object):
+    def sub(self, aggregate, **aggregates):
         aggregate['aggregations'] = aggregates
         return aggregate
 
-    def sum( self, field ):
+    def sum(self, field):
         return {
             'sum': {
                 'field': field
             }
         }
 
-    def avg( self, field ):
+    def avg(self, field):
         return {
             'avg': {
                 'field': field
             }
         }
 
-    def min( self, field ):
+    def min(self, field):
         return {
             'min': {
                 'field': field
             }
         }
 
-    def max( self, field ):
+    def max(self, field):
         return {
             'max': {
                 'field': field
             }
         }
 
-    def stats( self, field ):
+    def stats(self, field):
         return {
             'stats': {
                 'field': field
             }
         }
 
-    def extended_stats( self, field ):
+    def extended_stats(self, field):
         return {
             'extended_stats': {
                 'field': field
             }
         }
 
-    def missing( self, field ):
+    def missing(self, field):
         return {
             'missing': {
                 'field': field
             }
         }
 
-    def value_count( self, field ):
+    def value_count(self, field):
         return {
             'value_count': {
                 'field': field
             }
         }
 
-    def histogram( self, field, interval ):
+    def histogram(self, field, interval):
         try:
-            interval = int( interval )
+            interval = int(interval)
         except ValueError:
-            raise ElasticQueryError( 'interval must be a number' )
+            raise ElasticQueryError('interval must be a number')
 
         return {
             'histogram': {
@@ -207,7 +207,7 @@ class AggregateStructs( object ):
             }
         }
 
-    def date_histogram( self, field, interval='day' ):
+    def date_histogram(self, field, interval='day'):
         return {
             'date_histogram': {
                 'field': field,
@@ -215,17 +215,17 @@ class AggregateStructs( object ):
             }
         }
 
-    def terms( self, field, size=None, shard_size=None ):
+    def terms(self, field, size=None, shard_size=None):
         if size is None:
             size = 999999999
         if shard_size is None:
             shard_size = 999999999
 
         try:
-            size = int( size )
-            shard_size = int( shard_size )
+            size = int(size)
+            shard_size = int(shard_size)
         except ValueError:
-            raise ElasticQueryError( 'size/shard_size must be a number or None' )
+            raise ElasticQueryError('size/shard_size must be a number or None')
 
         return {
             'terms': {
@@ -235,14 +235,14 @@ class AggregateStructs( object ):
             }
         }
 
-    def nested( self, path ):
+    def nested(self, path):
         return {
             'nested': {
                 'path': path
             }
         }
 
-    def filter( self, musts=[], shoulds=[], must_nots=[] ):
+    def filter(self, musts=[], shoulds=[], must_nots=[]):
         must = [v[1] for v in musts]
         should = [v[1] for v in shoulds]
         must_not = [v[1] for v in must_nots]
@@ -261,4 +261,4 @@ class AggregateStructs( object ):
 # Init for importing
 Filter = FilterStructs()
 Query = QueryStructs()
-Aggregate = AggregateStructs()
\ No newline at end of file
+Aggregate = AggregateStructs()
